#include <iostream>
#include <string>
#include <memory.h>
#include <cstdio>
#include <algorithm>
#include <cmath>
#include <map>
#include <set>
#include <vector>
#include <fstream>
#include <queue>
#include <list>

using namespace std;
#define pb push_back
#define mp make_pair
#define FOR(i,a,b) for(int i=a;i<b;++i)
const int inf = 1000000001;
struct Dinic{
    int s, t, n;
    vector<int> d;
    vector<int> ptr;
    struct edge{
        int v, cap, flow;
    };

    vector<edge> e;
    vector< vector<int> > g;
    vector<int> q;

    Dinic(int _n, int _s, int _t) {
        n = _n;
        g.resize(n);
        ptr.resize(n);
        d.resize(n);
        q.resize(n+5);
        s = _s;
        t = _t;
    }

    void add_edge(int a, int b, int cap) {
        edge e1 = {b, cap, 0};
        edge e2 = {a, 0, 0};
        g[a].push_back(e.size());
        e.push_back(e1);
        g[b].push_back(e.size());
        e.push_back(e2);
    }

    bool bfs() {
        int qh = 0, qt = 0;
        for (int i = 0; i < n; ++i) d[i] = -1;
        d[s] = 0;
        q[qt++] = s;
        while (qh < qt) {
            int v = q[qh++];
            for (int i = 0; i < (int)g[v].size(); ++i) {
                int id = g[v][i];
                if (d[e[id].v] == -1 && e[id].cap != e[id].flow) {
                    d[e[id].v] = d[v] + 1;
                    q[qt++] = e[id].v;
                }
            }
        }
        return d[t] != -1;
    }

    int dfs(int v, int flow) {
        if (!flow || v == t) return flow;
        for (int &to = ptr[v]; to < (int)g[v].size(); ++to) {
            int id = g[v][to];
            if (d[e[id].v] != d[v] + 1) continue;
            int pushed = dfs(e[id].v, min(flow, e[id].cap - e[id].flow));
            if (pushed) {
                e[id].flow += pushed;
                e[id ^ 1].flow -= pushed;
                return pushed;
            }
        }
        return 0;
    }

    int dinic() {
        int flow = 0;
        for (;;) {
            if (!bfs()) break;
            for (int i = 0; i < n; ++i) ptr[i] = 0;
            while (int pushed = dfs(s, inf)) flow += pushed;
        }
        return flow;
    }

};

void solve() {
    int n, m;
    scanf("%d%d", &n, &m);
    int sval = 0, cval = 0, val;
    Dinic *A = new Dinic(2 + n + m, 0, n + m + 1);
    for (int i = 0; i < n; ++i) {
        scanf("%d", &val);
        sval += val; cval += val;
        if (val > 0) A->add_edge(0, i + 1, val);
    }

    for (int i = 0; i < m; ++i) {
        scanf("%d", &val);
        sval -= val;
        if (val > 0) A->add_edge(n + 1 + i, n + m + 1, val);
    }
    if (sval != 0) {
        puts("0");
        return;
    }
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            A->add_edge(i + 1, n + 1 + j, 1);
        }
    }
    int flow = A->dinic();
    if (flow == cval) puts("1"); else puts("0");
}

int main() {
    //freopen("input.txt", "r", stdin);
    freopen("puzzle.dat", "r", stdin);
    freopen("puzzle.sol", "w", stdout);
    int T;
    scanf("%d", &T);
    while (T--) {
        solve();
    }
    return 0;
}
