//created by Roman Rubanenko
#include <iostream>
#include <cstdio>
#include <vector>
#include <algorithm>
#include <math.h>
using namespace std;
const int INF = 2000000000;
long long ans = 0;
void findUnion(vector<pair<int, int> >& segments, int down, int up) { //pair<int,int> corresponds to segment [left, right]
    vector<pair<int, int> > events;
    for (int i = 0; i < segments.size(); i++) {
        pair<int, int> currentSegment = segments[i];
        if (currentSegment.first < down) {
            currentSegment.first = down;
        }
        if (currentSegment.second > up) {
            currentSegment.second = up;
        }
        if (currentSegment.first <= currentSegment.second) {
            events.push_back(currentSegment);
        }
    }
    sort(events.begin(), events.end());
    if (events.empty()) {
        return;
    }
    int lastCounted = events.front().first - 1;
    for (int i = 0; i < events.size(); i++) {
        pair<int, int> currentEvent = events[i];
        if (currentEvent.first > currentEvent.second || lastCounted >= currentEvent.second) {
            continue;
        }
        if (currentEvent.first > lastCounted) {
            ans += currentEvent.second - currentEvent.first + 1;
            lastCounted = currentEvent.second;
            continue;
        }
        ans += currentEvent.second - lastCounted;
        lastCounted = max(lastCounted, currentEvent.second);
    }
}
struct Point {
    int x, y;
    Point(int x, int y) : x(x), y(y) {}
    Point() {}
};
long long vectorProduct(Point& a, Point& b, Point& c) {
    return -(((long long)a.x - b.x) * (a.y + b.y) + ((long long)b.x - c.x) * (b.y + c.y) + ((long long)c.x - a.x) * (c.y + a.y));
}
bool cmp(Point a, Point b) {
    return (a.x < b.x) || (a.x == b.x && a.y < b.y);
}
int getRoot(long long value) {
    long long root = max(0, int(sqrt(value) - 1));
    while ((root + 1) * (root + 1) <= value) {
        root++;
    }
    return int(root);
}
double getIntersectionOrdinate(Point p1, Point p2, Point p3, Point p4) {
    double a1 = p1.y - p2.y;
    double b1 = p2.x - p1.x;
    double c1 = -a1 * p1.x - b1 * p1.y;
    double a2 = p3.y - p4.y;
    double b2 = p4.x - p3.x;
    double c2 = -a2 * p3.x - b2 * p3.y;
    return -(a1 * c2 - a2 * c1) / (a1 * b2 - a2 * b1);
}
int main() {
    freopen("trees.dat", "r", stdin);
    freopen("trees.sol", "w", stdout);
    int n, m;
    scanf("%d", &n);
    vector<Point> polygon;
    Point leftmost = Point(INF, INF), rightmost = Point(-INF, -INF);
    for (int i = 1; i <= n; i++) {
        int x, y;
        scanf("%d%d", &x, &y);
        polygon.push_back(Point(x, y));
        if (x < leftmost.x || (x == leftmost.x && y < leftmost.y)) {
            leftmost = {x, y};
        }
        if (rightmost.x < x || (x == rightmost.x && rightmost.y < y)) {
            rightmost = Point(x, y);
        }
    }
    vector<Point> top, bot;
    for (int i = 0; i < polygon.size(); i++) {
        Point point = polygon[i];
        long long orientedTriangleArea = vectorProduct(leftmost, rightmost, point);
        if (orientedTriangleArea >= 0) {
            bot.push_back(point);
        }
        if (orientedTriangleArea <= 0) {
            top.push_back(point);
        }
    }
    sort(top.begin(), top.end(), &cmp);
    sort(bot.begin(), bot.end(), &cmp);
    if (top[0].x == top[1].x) { //fixing vertical edges issue. there can be plenty of ways and this one is pretty personal
        for (int i = 1; i < top.size(); i++) {
            top[i - 1] = top[i];
        }
        top.pop_back();
    }
    if (bot[bot.size() - 1].x == bot[bot.size() - 2].x) {
        bot.pop_back();
    }
    scanf("%d", &m);
    vector<pair<int, pair<int, int> > > verticalSegments;
    for (int i = 1; i <= m; i++) {
        int x, y, r;
        scanf("%d%d%d", &x, &y, &r);
        for (int newX = x - r; newX <= x + r; newX++) {
            int dy = getRoot((long long)r * r - ((long long)newX - x) * (newX - x));
            verticalSegments.push_back({newX, {y - dy, y + dy}});
        }
    }
    sort(verticalSegments.begin(), verticalSegments.end());
    while (!verticalSegments.empty()) {
        vector<pair<int, int> > currentVerticalSegments;
        int currentX = verticalSegments.back().first;
        while (!verticalSegments.empty() && verticalSegments.back().first == currentX) {
            currentVerticalSegments.push_back(verticalSegments.back().second);
            verticalSegments.pop_back();
        }
        if (currentX < leftmost.x || currentX > rightmost.x) {
            continue;
        }
        int up, down, x;
        Point b1;
        while (!top.empty() && top.back().x >= currentX) {
            b1 = top.back();
            top.pop_back();
        }
        Point b2;
        while (!bot.empty() && bot.back(). x >= currentX) {
            b2 = bot.back();
            bot.pop_back();
        }
        if (currentX == b1.x) {
            up = b1.y;
        }
        else {
            Point a1 = top.back();
            int y = int(getIntersectionOrdinate(Point(currentX, 0), Point(currentX, 1), a1, b1)) + 1;
            Point tmp = Point(currentX, y);
            while (vectorProduct(a1, b1, tmp) < 0) {
                tmp.y--;
            }
            up = tmp.y;
        }
        if (currentX == b2.x) {
            down = b2.y;
        }
        else {
            Point a2 = bot.back();
            int y = int(getIntersectionOrdinate(Point(currentX, 0), Point(currentX, 1), a2, b2)) - 1;
            Point tmp = Point(currentX, y);
            while (vectorProduct(a2, b2, tmp) > 0) {
                tmp.y++;
            }
            down = tmp.y;
        }
        findUnion(currentVerticalSegments, down, up);
    }
    printf("%lld\n", ans);
};